using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using WpfApp1.WinOcr;
using WpfApp1.ScnToJson;
using WpfApp1.translationKey;
using WpfApp1.transToNet;

namespace testRjgc
{
    internal class AllClassAndInterfaceWellBeManipulatedInThisFileAndCallThroughFunction
    {
        AllClassAndInterfaceWellBeManipulatedInThisFileAndCallThroughFunction() { }

        public void InputPrivateBaidu(string name, string id, string key)
        {
            TranslationPrivateIn tr = new TranslationPrivateIn();
            tr.InputBaiduPrivate(name, id, key);
        }

        public void InPutPrivateA(string name, List<string> list)
        {
            TranslationPrivateIn tr = new TranslationPrivateIn();
            tr.InPutPrivate(name, list);
        }

        public List<string> OutputNameList()
        {
            TranslationApiStr tr = new translationPrivateOut();
            List<string> list = tr.OutputTranslationNameList();
            return list;
        }

        public List<string> OutputStr(string id)
        {
            TranslationApiStr str = new translationPrivateOut();
            List<string> li = str.OutputTranslationS(id);
            return li;
        }

        public List<string> OutputChoicPublic(int id)
        {
            TranslationApiInt sin = new translationPublic();
            List<string> li = sin.OutputTranslationI(id);
            return li;
        }

        public void StartSCNTransJSON()
        {
            TranslationScnToJson scn = new TranslationScnToJson();
            scn.StartTrans();
        }

        public void StartTransOneself(string spa, string dps)
        {
            TranslationScnToJson scn = new TranslationScnToJson();
            scn.StopTrans(spa, dps);
        }

        public string WindowsOcrToGetString(string name)
        {
            Sofia so = new OcrSofia();
            string temp = so.WindowsOcrToGetStringAndTranslate(name);
            return temp;
        }

        public string NetBaiDu(string input)
        {
            Messiah me = new jsonNet();
            return me.RequestJsonBaiDu(input);
        }

        public string NetAllBaiDu(string input, string srcl, string dstl, string aid, string kkey)
        {
            Messiah me = new jsonNet();
            return me.RequestJsonPrivateBaiDu(input, srcl, dstl, aid, kkey);
        }

        public string NetLanBaiDu(string input, string srcl, string dstl)
        {
            Messiah me = new jsonNet();
            return me.RequestJsonLanguageChangeBaiDu(input, srcl, dstl);
        }

        public string NetXunFei(string input)
        {
            Messiah me = new jsonNet();
            return me.RequestJsonXunFei(input);
        }

        public string NetLanXunFei(string input, string srcl, string dstl)
        {
            Messiah me = new jsonNet();
            return me.RequestJsonLanguageChangeXunFei(input, srcl, dstl);
        }

        public string NetAllXunFei(string input, string srcl, string dstl, string xid, string xsecret, string xkey)
        {
            Messiah me = new jsonNet();
            return me.RequestJsonPrivateXunFei(input, srcl, dstl, xid, xsecret, xkey);
        }


    }
}
